@@ -1,7 +1,7 @@
 from concurrent.futures import ThreadPoolExecutor
 from functools import partial
 from multiprocessing import cpu_count
-from typing import Any, Callable, List
+from typing import Any, Callable, List, Optional
 
 from parallely.base import ParalellyFunction
 from parallely.utils import prepare_arguments
@@ -21,13 +21,16 @@ class ThreadedFunction(ParalellyFunction):
         return [future.result() for future in futures]
 
 
-def threaded(func: Callable = None, max_workers: int = cpu_count() * 10) -> ThreadedFunction:
+def threaded(func: Callable = None, max_workers: Optional[int] = None) -> ThreadedFunction:
     """
 
     :param func:
     :param max_workers:
     :return:
     """
+
+    max_workers = max_workers if max_workers is not None else cpu_count() * 10
+
     if func is None:
         return partial(threaded, max_workers=max_workers)
 
